/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2007,2008 Bull S.A.S.
 * Contact: cmi@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: CMIProperty.java 2438 2010-02-24 16:20:30Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.config;

/**
 * Properties to configure CMI.
 * @author Loris Bouzonnet
 */
public enum CMIProperty {

    /**
     * Property name for specifying if the CMI Server is automatically started when creating a first CMI context.
     */
    AUTOSTART("cmi.manager.autostart"),

    /**
     * Property name for specifying the ServerClusterViewManager.
     */
    REPLICATION_MANAGER_CLASS("cmi.server.impl.class"),

    /**
     * Property name for specifying the directory where load balancing archives
     * will be deployed.
     */
    DEPLOY_DIRECTORY("cmi.server.deploy.directory"),

    /**
     * Property name to declare name of the ClientClusterViewProvider that is
     * used to bind it.
     */
    PROVIDER_BIND_NAME("cmi.context.provider.bind.name"),

    /**
     * Property name to declare name of the dummy context that is used to bind
     * it.
     */
    DUMMY_CONTEXT_BIND_NAME("cmi.context.jndi.bind.name"),

    /**
     * Property name to declare a list of provider URLs to access to a provider
     * of the cluster view. This property must be defined in the case of servers
     * using a cmi client (ie having a client-side manager).
     */
    CLUSTER_VIEW_PROVIDER_URLS("cmi.context.provider.urls"),

    /**
     * Property to indicate the path to get the configuration files.
     */
    CONF_DIR("cmi.conf.dir"),

    /**
     * Property to indicate the configuration filename.
     */
    CONF_FILENAME("cmi.conf.filename"),

    /**
     * Property to define the wrapped InitialContextFactory.
     */
    WRAPPED_INITIAL_CONTEXT_FACTORY("cmi.context.wrapped.factory"),

    /**
     * Property to define the protocol.
     */
    WRAPPED_PROTOCOL("cmi.context.wrapped.protocol"),

    /**
     * Property to define the local registry URL.
     */
    LOCAL_REGISTRY_URL("cmi.context.registry.url"),

    /**
     * Property to specify if we are in server mode.
     */
    SERVER_MODE("cmi.mode.server");


    /**
     * A name of property.
     */
    private final String propertyName;

    /**
     * @param propertyName
     *            a name of property
     */
    CMIProperty(final String propertyName) {
        this.propertyName = propertyName;
    }

    /**
     * @return the name of property
     */
    @Override
    public String toString() {
        return propertyName;
    }

    /**
     * @return the name of property
     */
    public String getPropertyName() {
        return propertyName;
    }
}
